@@ -1,15 +1,16 @@
 package File::Append::Undoable;
 
+our $DATE = '2015-08-17'; # DATE
+our $VERSION = '0.03'; # VERSION
+
 use 5.010001;
 use strict;
 use warnings;
-use Log::Any '$log';
+use Log::Any::IfLOG '$log';
 
 use File::Trash::Undoable;
 use File::Copy;
 
-our $VERSION = '0.02'; # VERSION
-
 our %SPEC;
 
 $SPEC{append} = {
@@ -134,15 +135,20 @@ File::Append::Undoable - Append string to a file, with undo support
 
 =head1 VERSION
 
-This document describes version 0.02 of File::Append::Undoable (from Perl distribution File-Append-Undoable), released on 2014-05-17.
+This document describes version 0.03 of File::Append::Undoable (from Perl distribution File-Append-Undoable), released on 2015-08-17.
+
+=head1 SEE ALSO
+
+L<Rinci::Transaction>
 
 =head1 FUNCTIONS
 
 
 =head2 append(%args) -> [status, msg, result, meta]
 
-Append string to a file, with undo support.
+{en_US Append string to a file, with undo support}.
 
+{en_US 
 On do, will trash file, copy it to original location (with the same permission
 and ownership as the original) and append the string to the end of file. On undo
 will trash the new file and untrash the original.
@@ -151,32 +157,16 @@ Some notes:
 
 =over
 
-=item *
+=item * Chown will not be done if we are not running as root.
 
-Chown will not be done if we are not running as root.
-
-
-
-=item *
-
-Symlink is currently not permitted.
-
-
-
-=item *
-
-Since transaction requires the function to be idempotent, in the C<check_state>
-  phase the function will check if the string has been appended. It will refuse
-  to append the same string twice.
-
-
-
-=item *
-
-Take care not to use string that are too large, as the string, being a
-  function parameter, is entered into the transaction table.
+=item * Symlink is currently not permitted.
 
+=item * Since transaction requires the function to be idempotent, in the C<check_state>
+phase the function will check if the string has been appended. It will refuse
+to append the same string twice.
 
+=item * Take care not to use string that are too large, as the string, being a
+function parameter, is entered into the transaction table.
 
 =back
 
@@ -186,6 +176,7 @@ Fixable state: file exists and string has not been appended to end of file.
 
 Unfixable state: file does not exist or path is not a regular file (directory
 and symlink included).
+}
 
 This function is idempotent (repeated invocations with same arguments has the same effect as single invocation). This function supports transactions.
 
@@ -196,11 +187,11 @@ Arguments ('*' denotes required arguments):
 
 =item * B<path>* => I<str>
 
-The file to append.
+{en_US The file to append}.
 
 =item * B<string>* => I<any>
 
-The string to append to file.
+{en_US The string to append to file}.
 
 =back
 
@@ -230,8 +221,6 @@ For more information on transaction, see L<Rinci::Transaction>.
 
 =back
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -241,9 +230,7 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
-=head1 SEE ALSO
-
-L<Rinci::Transaction>
+Return value:  (any)
 
 =head1 HOMEPAGE
 
@@ -263,11 +250,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
